@@ -47,7 +47,7 @@ setGeneric("as.array",
   function(x,...)standardGeneric("as.array")
   )
 
-contrasts <- function(x,...) stats::contrasts(x,...)
+#contrasts <- function(x,...) stats::contrasts(x,...)
 setGeneric("contrasts",
   function(x,...) standardGeneric("contrasts")
 )
@@ -55,4 +55,10 @@ setGeneric("contrasts",
 # "contrasts<-" <- function(x,how.many,value) stats::`contrasts<-`(x,how.many,value)
 # setGeneric("contrasts<-",
 #   function(x,how.many,value) standardGeneric("contrasts<-")
-# )
\ No newline at end of file
+# )
+
+Write <- function(x,...) UseMethod("Write")
+
+# setGeneric("Write",
+#            function(object,...)
+#              standardGeneric("Write"))
