@@ -96,61 +96,6 @@ function (which.given, which.panel, var.name, factor.levels,
     grid::upViewport()
 }
 
-## Copied from lattice, because R CMD --check warns about lattice:::paste.and.draw
-paste.and.draw <-
-    function(left, right, sep = " : ",
-             horizontal = TRUE,
-             center = TRUE,
-             showl = TRUE,
-             showr = TRUE,
-             gp = gpar())
-{
-    ## We are already in a viewport.  Essentially want to draw
-    ## paste(left, right, sep = sep) in the middle.  The catch is,
-    ## left and right (maybe even sep) may be expressions.  The easy
-    ## solution is to draw sep in the middle and left and right on
-    ## either side.  The better solution is to combine and then
-    ## center.
-
-    if (showl || showr)
-    {
-        shows <- showl && showr
-        wsep <- unit(0.5 * shows, "strwidth", list(sep))
-        offset <- unit(0.5, "npc")
-        if (center)
-            offset <-
-                offset +
-                    (if (showl) unit(0.5, "strwidth", list(left)) else unit(0, "mm")) -
-                        (if (showr) unit(0.5 * showr, "strwidth", list(right)) else unit(0, "mm"))
-        if (horizontal)
-        {
-            if (shows) grid.text(sep, x = offset,
-                                 name = trellis.grobname("sep", type="strip"),
-                                 gp = gp)
-            if (showl) grid.text(left, x = offset - wsep,
-                                 name = trellis.grobname("textl", type="strip"),
-                                 gp = gp, just = "right")
-            if (showr) grid.text(right, x = offset + wsep,
-                                 name = trellis.grobname("textr", type="strip"),
-                                 gp = gp, just = "left")
-        }
-        else
-        {
-            if (shows) grid.text(sep, y = offset,
-                                 name = trellis.grobname("sep", type="strip.left"),
-                                 gp = gp, rot = 90)
-            if (showl) grid.text(left, y = offset - wsep,
-                                 name = trellis.grobname("textl", type="strip.left"),
-                                 gp = gp, just = "right", rot = 90)
-            if (showr) grid.text(right, y = offset + wsep,
-                                 name = trellis.grobname("textr", type="strip.left"),
-                                 gp = gp, just = "left", rot = 90)
-        }
-    }
-}
-
-
-
 Termplot <- function(object,...) UseMethod("Termplot")
 
 Termplot.default <- function(object,
